@@ -76,15 +76,15 @@ class Snake():
         newY = self._y - round(amount * math.cos(math.radians(self._rotation)), 1)
         self._moveTo(newX, newY)
     
-    def display(self):
+    def display(self, canvWidth = 400, canvHeight = 200):
         # for some reason it is not doing the last 2 actions... sooooo
         self.goforward(1)
         self.turnright(1)
-        #self._randHash = random.getrandbits(128)
-        self._randHash = "asForTurtle";
+        self._randHash = random.getrandbits(128)
+        #self._randHash = "asForTurtle";
         ## Canvas creation
         display(HTML('<script type="text/javascript">%s</script>'%ReadFile('paper.js')))
-        display(HTML('<canvas id="canv%s" width=400px height=200px></canvas>'%self._randHash))
+        display(HTML('<canvas id="canv%s" width=%spx height=%spx></canvas>'%(self._randHash, canvWidth, canvHeight)))
         
         
         ## Data injection
